==> dojo-1.9.4.tgz: package/cldr/nls/fr/buddhist.js <==
define(
//begin v1.x content
{
	"field-dayperiod": "cadran",
	"dateFormatItem-yyyyMMMEd": "E d MMM y G",
	"field-minute": "minute",
	"eraNames": [
		"ère bouddhiste"
	],
	"dateFormatItem-MMMEd": "E d MMM",
	"field-day-relative+-1": "hier",
	"field-weekday": "jour de la semaine",
	"field-day-relative+-2": "avant-hier",
	"days-standAlone-wide": [
		"dimanche",
		"lundi",
		"mardi",
		"mercredi",
		"jeudi",
		"vendredi",
		"samedi"
	],
	"months-standAlone-narrow": [
		"J",
		"F",
		"M",
		"A",
		"M",
		"J",
		"J",
		"A",
		"S",
		"O",
		"N",
		"D"
	],
	"field-era": "ère",
	"dateFormatItem-Gy": "y G",
	"field-hour": "heure",
	"quarters-standAlone-abbr": [
		"T1",
		"T2",
		"T3",
		"T4"
	],
	"dateFormatItem-y": "y G",
	"dateFormatItem-yyyy": "y G",
	"months-standAlone-abbr": [
		"janv.",
		"févr.",
		"mars",
		"avr.",
		"mai",
		"juin",
		"juil.",
		"août",
		"sept.",
		"oct.",
		"nov.",
		"déc."
	],
	"dateFormatItem-Ed": "E d",
	"field-day-relative+0": "aujourd’hui",
	"field-day-relative+1": "demain",
	"days-standAlone-narrow": [
		"D",
		"L",
		"M",
		"M",
		"J",
		"V",
		"S"
	],
	"eraAbbr": [
		"ère b."
	],
	"field-day-relative+2": "après-demain",
	"dateFormatItem-GyMMMd": "d MMM y G",
	"dateFormat-long": "d MMMM y G",
	"field-zone": "fuseau horaire",
	"field-week-relative+-1": "la semaine dernière",
	"dateFormat-medium": "d MMM y G",
	"dayPeriods-format-narrow-pm": "p",
	"field-year-relative+0": "cette année",
	"field-year-relative+1": "l’année prochaine",
	"quarters-standAlone-wide": [
		"1er trimestre",
		"2e trimestre",
		"3e trimestre",
		"4e trimestre"
	],
	"field-year-relative+-1": "l’année dernière",
	"field-year": "année",
	"dateFormatItem-yyyyQQQQ": "QQQQ y G",
	"field-week": "semaine",
	"months-standAlone-wide": [
		"janvier",
		"février",
		"mars",
		"avril",
		"mai",
		"juin",
		"juillet",
		"août",
		"septembre",
		"octobre",
		"novembre",
		"décembre"
	],
	"dateFormatItem-yyyyMMMd": "d MMM y G",
	"dateFormatItem-yyyyMd": "d/M/y GGGGG",
	"dateFormatItem-yyyyMEd": "E d/M/y GGGGG",
	"field-week-relative+0": "cette semaine",
	"dateFormatItem-MMMd": "d MMM",
	"field-week-relative+1": "la semaine prochaine",
	"months-format-abbr": [
		"janv.",
		"févr.",
		"mars",
		"avr.",
		"mai",
		"juin",
		"juil.",
		"août",
		"sept.",
		"oct.",
		"nov.",
		"déc."
	],
	"field-month-relative+0": "ce mois-ci",
	"field-month": "mois",
	"field-month-relative+1": "le mois prochain",
	"quarters-format-abbr": [
		"T1",
		"T2",
		"T3",
		"T4"
	],
	"days-format-abbr": [
		"dim.",
		"lun.",
		"mar.",
		"mer.",
		"jeu.",
		"ven.",
		"sam."
	],
	"days-format-narrow": [
		"D",
		"L",
		"M",
		"M",
		"J",
		"V",
		"S"
	],
	"field-second": "seconde",
	"dateFormatItem-GyMMMEd": "E d MMM y G",
	"dateFormatItem-GyMMM": "MMM y G",
	"field-day": "jour",
	"dateFormatItem-yyyyQQQ": "QQQ y G",
	"dateFormatItem-MEd": "E d/M",
	"months-format-narrow": [
		"J",
		"F",
		"M",
		"A",
		"M",
		"J",
		"J",
		"A",
		"S",
		"O",
		"N",
		"D"
	],
	"days-standAlone-short": [
		"dim.",
		"lun.",
		"mar.",
		"mer.",
		"jeu.",
		"ven.",
		"sam."
	],
	"days-standAlone-abbr": [
		"dim.",
		"lun.",
		"mar.",
		"mer.",
		"jeu.",
		"ven.",
		"sam."
	],
	"dateFormat-short": "dd/MM/y GGGGG",
	"dateFormatItem-yyyyM": "M/y GGGGG",
	"dateFormat-full": "EEEE d MMMM y G",
	"dateFormatItem-Md": "d/M",
	"months-format-wide": [
		"janvier",
		"février",
		"mars",
		"avril",
		"mai",
		"juin",
		"juillet",
		"août",
		"septembre",
		"octobre",
		"novembre",
		"décembre"
	],
	"days-format-short": [
		"di",
		"lu",
		"ma",
		"me",
		"je",
		"ve",
		"sa"
	],
	"dateFormatItem-yyyyMMM": "MMM y G",
	"field-month-relative+-1": "le mois dernier",
	"quarters-format-wide": [
		"1er trimestre",
		"2e trimestre",
		"3e trimestre",
		"4e trimestre"
	],
	"eraNarrow": "E.B.",
	"days-format-wide": [
		"dimanche",
		"lundi",
		"mardi",
		"mercredi",
		"jeudi",
		"vendredi",
		"samedi"
	]
}
//end v1.x content
);

==> dojo-1.14.2.tgz: package/cldr/nls/fr/buddhist.js <==
define(
//begin v1.x content
{
	"days-standAlone-short": [
		"Di",
		"Lu",
		"Ma",
		"Me",
		"Je",
		"Ve",
		"Sa"
	],
	"months-format-narrow": [
		"J",
		"F",
		"M",
		"A",
		"M",
		"J",
		"J",
		"A",
		"S",
		"O",
		"N",
		"D"
	],
	"field-second-relative+0": "maintenant",
	"field-weekday": "jour de la semaine",
	"field-wed-relative+0": "ce mercredi",
	"field-wed-relative+1": "mercredi prochain",
	"dateFormatItem-GyMMMEd": "E d MMM y G",
	"dateFormatItem-MMMEd": "E d MMM",
	"eraNarrow": "E.B.",
	"field-tue-relative+-1": "mardi dernier",
	"days-format-short": [
		"di",
		"lu",
		"ma",
		"me",
		"je",
		"ve",
		"sa"
	],
	"dateFormat-long": "d MMMM y G",
	"field-fri-relative+-1": "vendredi dernier",
	"field-wed-relative+-1": "mercredi dernier",
	"months-format-wide": [
		"janvier",
		"février",
		"mars",
		"avril",
		"mai",
		"juin",
		"juillet",
		"août",
		"septembre",
		"octobre",
		"novembre",
		"décembre"
	],
	"dateFormatItem-yyyyQQQ": "QQQ y G",
	"dateFormat-full": "EEEE d MMMM y G",
	"dateFormatItem-yyyyMEd": "E d/M/y GGGGG",
	"field-thu-relative+-1": "jeudi dernier",
	"dateFormatItem-Md": "d/M",
	"dayPeriods-format-wide-noon": "midi",
	"field-era": "ère",
	"months-standAlone-wide": [
		"Janvier",
		"Février",
		"Mars",
		"Avril",
		"Mai",
		"Juin",
		"Juillet",
		"Août",
		"Septembre",
		"Octobre",
		"Novembre",
		"Décembre"
	],
	"quarters-format-wide": [
		"1er trimestre",
		"2e trimestre",
		"3e trimestre",
		"4e trimestre"
	],
	"field-year": "année",
	"field-hour": "heure",
	"months-format-abbr": [
		"janv.",
		"févr.",
		"mars",
		"avr.",
		"mai",
		"juin",
		"juil.",
		"août",
		"sept.",
		"oct.",
		"nov.",
		"déc."
	],
	"field-sat-relative+0": "ce samedi",
	"field-sat-relative+1": "samedi prochain",
	"field-day-relative+0": "aujourd’hui",
	"field-thu-relative+0": "ce jeudi",
	"field-day-relative+1": "demain",
	"field-thu-relative+1": "jeudi prochain",
	"dateFormatItem-GyMMMd": "d MMM y G",
	"field-day-relative+2": "après-demain",
	"months-standAlone-abbr": [
		"Janv.",
		"Févr.",
		"Mars",
		"Avr.",
		"Mai",
		"Juin",
		"Juil.",
		"Août",
		"Sept.",
		"Oct.",
		"Nov.",
		"Déc."
	],
	"quarters-format-abbr": [
		"T1",
		"T2",
		"T3",
		"T4"
	],
	"quarters-standAlone-wide": [
		"1er trimestre",
		"2e trimestre",
		"3e trimestre",
		"4e trimestre"
	],
	"dateFormatItem-Gy": "y G",
	"dateFormatItem-yyyyMMMEd": "E d MMM y G",
	"dateFormatItem-M": "L",
	"days-standAlone-wide": [
		"Dimanche",
		"Lundi",
		"Mardi",
		"Mercredi",
		"Jeudi",
		"Vendredi",
		"Samedi"
	],
	"dateFormatItem-yyyyMMM": "MMM y G",
	"dateFormatItem-yyyyMMMd": "d MMM y G",
	"field-sun-relative+0": "ce dimanche",
	"field-sun-relative+1": "dimanche prochain",
	"quarters-standAlone-abbr": [
		"T1",
		"T2",
		"T3",
		"T4"
	],
	"eraAbbr": [
		"ère b."
	],
	"field-minute": "minute",
	"field-dayperiod": "cadran",
	"days-standAlone-abbr": [
		"Dim.",
		"Lun.",
		"Mar.",
		"Mer.",
		"Jeu.",
		"Ven.",
		"Sam."
	],
	"dateFormatItem-d": "d",
	"field-day-relative+-1": "hier",
	"dateTimeFormat-long": "{1} 'à' {0}",
	"field-day-relative+-2": "avant-hier",
	"dateFormatItem-MMMd": "d MMM",
	"dateFormatItem-MEd": "E d/M",
	"dateTimeFormat-full": "{1} 'à' {0}",
	"field-fri-relative+0": "ce vendredi",
	"field-fri-relative+1": "vendredi prochain",
	"field-day": "jour",
	"days-format-wide": [
		"dimanche",
		"lundi",
		"mardi",
		"mercredi",
		"jeudi",
		"vendredi",
		"samedi"
	],
	"field-zone": "fuseau horaire",
	"dateFormatItem-y": "y G",
	"months-standAlone-narrow": [
		"J",
		"F",
		"M",
		"A",
		"M",
		"J",
		"J",
		"A",
		"S",
		"O",
		"N",
		"D"
	],
	"field-year-relative+-1": "l’année dernière",
	"field-month-relative+-1": "le mois dernier",
	"days-format-abbr": [
		"dim.",
		"lun.",
		"mar.",
		"mer.",
		"jeu.",
		"ven.",
		"sam."
	],
	"eraNames": [
		"ère bouddhiste"
	],
	"days-format-narrow": [
		"D",
		"L",
		"M",
		"M",
		"J",
		"V",
		"S"
	],
	"dateFormatItem-yyyyMd": "d/M/y GGGGG",
	"field-month": "mois",
	"dateFormatItem-MMM": "LLL",
	"days-standAlone-narrow": [
		"D",
		"L",
		"M",
		"M",
		"J",
		"V",
		"S"
	],
	"field-tue-relative+0": "ce mardi",
	"field-tue-relative+1": "mardi prochain",
	"field-mon-relative+0": "ce lundi",
	"field-mon-relative+1": "lundi prochain",
	"dateFormat-short": "dd/MM/y GGGGG",
	"dayPeriods-format-narrow-noon": "midi",
	"field-second": "seconde",
	"field-sat-relative+-1": "samedi dernier",
	"field-sun-relative+-1": "dimanche dernier",
	"field-month-relative+0": "ce mois-ci",
	"field-month-relative+1": "le mois prochain",
	"dateFormatItem-Ed": "E d",
	"field-week": "semaine",
	"dateFormat-medium": "d MMM y G",
	"field-year-relative+0": "cette année",
	"field-week-relative+-1": "la semaine dernière",
	"dateFormatItem-yyyyM": "M/y GGGGG",
	"field-year-relative+1": "l’année prochaine",
	"dateFormatItem-yyyyQQQQ": "QQQQ y G",
	"dateFormatItem-GyMMM": "MMM y G",
	"field-mon-relative+-1": "lundi dernier",
	"dateFormatItem-yyyy": "y G",
	"field-week-relative+0": "cette semaine",
	"field-week-relative+1": "la semaine prochaine"
}
//end v1.x content
);
